Range

Derive Macro Range 

#[derive(Range)]
The derive macro #[derive(Range)] is used to implement the Range trait by default for a struct.
By default the range trait will not add any range to the Query.